@@ -291,8 +291,6 @@ class monitoring2:
 		'''
 		Получение кодов агента по id ККТ
 		'''
-		if len(rnm)!=16: return
-		kkm_id=self.seek_kkm(rnm)['id']
 		self.r=self.seek_kkm_by_id(kkm_id)
 		self.agentCodes=[{'kkm_id':kkm_id, 'agentCode':x.get('agentCode', '0000000000'), 'serviceId': x['id']} for x in self.r['kkmModel']['serviceLog']]
 
